# imagepile

Image tools for large image repositories

# Usage

For more information on the command-line interface, type:

```bash
imagepile --help
```

```
usage: imagepile [-h] folderpath

Remove invalid images from a folder

positional arguments:
  folderpath

optional arguments:
  -h, --help  show this help message and exit
```

# License

This project is licensed under the MIT license. See the [LICENSE](LICENSE) for details.
